@@ -46,10 +46,19 @@ class Media(object):
         if self.exists:
             MEDIA.set(self.filename, self.duration)
 
+    @staticmethod
+    def __all__():
+        """Retourne la liste complète des fichiers media existants.
+        Juste les noms des fichiers"""
+        return [
+            i for i in os.listdir(CONFIG['APP']['media_folder'])
+            if i.endswith('.ts')
+            ]
+
     @staticmethod
     def all():
         """Retourne la liste complète des fichiers media existants"""
-        return [Media(i) for i in os.listdir(CONFIG['APP']['media_folder'])]
+        return [Media(i) for i in Media.__all__()]
 
     @staticmethod
     def update():
